from datetime import datetime, timezone
from data import AutosavedPlayer

def handle_claim(player: AutosavedPlayer) -> None:
    """Claim gold based on the last claim timestamp."""
    now = datetime.now(timezone.utc)  # Use UTC time
    
    if player.last_claim_timestamp is None:
        # If the player has never claimed, just set it to now
        player.last_claim_timestamp = now
        player.save()
        print("You have claimed your first reward of 100 gold!")
        player.gold += 100
        return

    # Calculate time difference since last claim
    time_offline = now - player.last_claim_timestamp
    minutes_offline = int(time_offline.total_seconds() // 60)
    gold_gain = minutes_offline
    if minutes_offline < 1:
        print("You haven't been offline for long enough to get any rewards!")
        return
    
    player.gold += gold_gain
    
    # Update last claim timestamp to now
    player.last_claim_timestamp = now
    
    print(f"You have claimed {gold_gain} gold for being offline for {minutes_offline} minutes!")



from setuptools import setup, find_packages

setup(
    name='idlegame',
    version='1.0.2',
    packages=find_packages(),
    install_requires=[
        # TODO: dependencies here
    ],
    entry_points={
        'console_scripts': [
            'idlegame=idlegame.main:main',  # Existing entry point
        ],
        'gui_scripts': [  # This line enables running via python command
            'idlegame=idlegame.main:main',
        ],
    },
    description='A tiny idle game you can play right from your terminal, if you are bored at your software development job',
    author='Ben Boonstra',
    license='MIT',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    python_requires='>=3.6',
)
